# doGPT 🐶

Advanced AI, but for dogs. 

## Animal welfare statement

No animals were harmed during the development of this advanced AI.

## Installation

Ensure you have Python installed, then:

```
$ pip install dogpt
```

## Usage

Simply call the `dogpt` command from the terminal with some prompt text:

```
$ dogpt in your considered opinion, what is the meaning of life?
```

The output will display, with pauses (this is advanced AI that requires
significant computational resources), to the terminal:

```
woof play woof arf woof tummy rub sniff grrr
```

## API usage

From within your code:

```python
from dogpt import text

prompt = input("What do you want to say to the dog? ")
text(prompt)
```

This fragment will pipe out the response to `STDOUT`.

## Contributing

We welcome contributions from advanced AI researchers, funding in the order of
millions of dollars from billionaires, and canine related training skills via
our [GitHub page](https://github.com/ntoll/doGPT).
